import os
import datetime
import openpyxl as xls
import matplotlib.pyplot as plt
import csv
import numpy as np
import re
# import tkinter


def get_new_dir():
    # save the current time
    current_date = str(datetime.datetime.now().year) + "_" + str(datetime.datetime.now().month) + "_" + str(
        datetime.datetime.now().day)

    # get current directory
    file_directory = os.path.dirname(os.path.realpath(__file__))[0:-27]
    excel_directory = os.path.dirname(os.path.realpath(__file__))[0:-27] + "main.xlsm"
    new_file_directory = os.path.dirname(os.path.realpath("__file__"))[0:-27] + "measurement"

    # create the new directory for the results
    for i in range(99):
        if not os.path.isdir(new_file_directory + "\\" + current_date + '_try' + ret_num_with_leading_zeros(i)):
            # we can create a folder with try i number
            try:
                new_file_directory = new_file_directory + "\\" + current_date + '_try' + ret_num_with_leading_zeros(
                    i)
                os.mkdir(new_file_directory)
                report_the_info("Your data will be stored in location: \n" + str(
                    new_file_directory) + "\n Copy the address to the clipboard")
                break
            except:
                report_the_bug("Nie udalo sie utworzyc pliku!")
                break
        else:
            pass
    return file_directory, excel_directory, new_file_directory


def ret_num_with_leading_zeros(number):
    str_num = str("{:02d}".format(number))
    return str_num


def report_the_info(info):

    print(info)


def report_the_bug(bug):
    print("Error occured: " + bug)


def get_values_from_excel(directory, sheet_name):
    frequency = []
    duty_cycle = []
    voltage = []

    workbook = xls.load_workbook(filename=directory, read_only=True)
    sheet = workbook[sheet_name]

    current_ch = sheet['P11'].value
    voltage_ch = sheet['Q11'].value
    trigger_ch = sheet['R11'].value
    new_file_directory_excel = sheet['R13'].value

    generator_add = sheet['C5'].value
    oscilloscope_add = sheet['P5'].value

    for row in range(sheet.max_row):

        data_F = sheet['C' + str(row + 16)].value
        data_DC = sheet['F' + str(row + 16)].value
        data_V = sheet['K' + str(row + 16)].value

        if data_F is not None:
            frequency.append(float(data_F))
        if data_DC is not None:
            duty_cycle.append(float(data_DC))
        if data_V is not None:
            voltage.append(float(data_V))
    workbook.close()
    return frequency, duty_cycle, voltage, current_ch, voltage_ch, trigger_ch, new_file_directory_excel, generator_add, oscilloscope_add


def show_data(curr_data, vol_data, freq, vol):
    plt.figure()
    x1 = np.linspace(0, 100, len(curr_data))
    x2 = np.linspace(0, 100, len(vol_data))
    plt.plot(x1, curr_data, 'r-', x2, vol_data, 'g-', label=['Frequency', 'Voltage'])
    # plt.label('Frequency', 'Voltage')
    plt.suptitle("Freq: " + str(freq) + ", Voltage: " + str(vol))
    plt.grid(True)
    plt.draw()


def save_data_to_file(file, tab_data_curr, tab_data_vol):
    with open(file=file, mode='a', newline='') as f:
        csv_writer = csv.writer(f, delimiter=';')

        csv_writer.writerow(["Voltage", "Current"])

        for curr, vol in zip(tab_data_curr, tab_data_vol):
            csv_writer.writerow([str(curr), str(vol)])

        f.close()
        #


def normalize_from_string(nor1, nor2):
    lookUp = {'uV': '10e-6',
              'mV': '10e-3',
              'V': '1',
              'kV': '1000',
              'uA': '10e-6',
              'mA': '10e-3',
              'A': '1',
              'kA': '1000'
              }


    mul_WFM1 = nor1[6][1:-1].split(',')
    mul_WFM2 = nor2[6][1:-1].split(',')

    split_info_1 = re.split('(\d+)', mul_WFM1[2])
    split_info_2 = re.split('(\d+)', mul_WFM2[2])
    #
    # print("NOR1: ", nor1)
    # print("NOR2: ", nor2)
    # print("mul_WFM1: ", mul_WFM1)
    # print("mul_WFM2: ", mul_WFM2)

    # mul1 = split_info_1[1]
    # mul2 = split_info_2[1]
    unit1 = split_info_1[-1].split('/')[0]
    unit2 = split_info_2[-1].split('/')[0]
    # print("MUL 1: " + str(mul1))
    # print("MUL 2: " + str(mul2))
    # print("UNIT 1: " + str(unit1))
    # print("UNIT 2: " + str(unit2))

    mul1 = float(lookUp[unit1])
    mul2 = float(lookUp[unit2])
    # print("FIN 1: " + str(mul1))
    # print("FIN 1: " + str(mul2))
    #
    # print(split_info_1)
    # print(split_info_2)

    mul1 = float(nor1[-5])
    mul2 = float(nor2[-5])
    #
    # print("FIN MUL 1: " + str(mul1))
    # print("FIN MUL 2: " + str(mul2))
    return mul1, mul2
