import pyvisa as visa
import time
import functions as fun
import oscilloscope_functions as osc_fun
import generator_functions as gen_fun
import powersupply_functions as pow_fun
import matplotlib.pyplot as plt
import sys

# get dir
file_directory, excel_directory, new_file_directory = fun.get_new_dir()

# needfuly data from excel
frequency_tab, duty_cycle_tab, voltage_tab, current_ch, voltage_ch, trigger_ch, pow_sup_ch, generator_add, oscilloscope_add, pow_sup_add = fun.get_values_from_excel(excel_directory, "Main")

# find devices
rm = visa.ResourceManager()

time.sleep(0.1)

try:
    # create devices
    generator = rm.open_resource('USB0::0x0957::0x0407::MY43001391::INSTR')
    scope = rm.open_resource('USB0::0x0699::0x0522::C013467::INSTR')
    pow_sup = rm.open_resource('USB0::0x05E6::0x2230::802900012747220022::INSTR')

    # noinspection PyUnresolvedReferences
    fun.report_the_info('Scope, connected to: ' + scope.query('*IDN?').__str__() +
                        'Generator, connected to: ' + generator.query('*IDN?').__str__() +
                        'Power supply, connected to: ' + pow_sup.query('*IDN?').__str__())
except Exception as exception:
    fun.report_the_bug("Error during linking one of needful devices\n" + exception.__str__() +
                       '\n Check if the all USB cables are connected to your computer as well as to the devices')
    sys.exit()

# set up all devices
current_meas, voltage_meas = osc_fun.set_up_device(scope=scope,
                                                   generator=generator,
                                                   freq=frequency_tab[0],
                                                   volt=voltage_tab[0],
                                                   directory=new_file_directory,
                                                   triger_ch=trigger_ch,
                                                   voltage_ch=voltage_ch,
                                                   current_ch=current_ch)
gen_fun.set_up_device(generator)
pow_fun.set_up_device(pow_sup, pow_sup_ch)

time.sleep(0.5)

##############
# tutaj mozna dodac wyskakujace okno ktore poinformuje ktore urzadzenia sa podpiete
##############


for voltage in voltage_tab:
    for frequency in frequency_tab:
        # wylacz urzadzenia
        pow_fun.disable_outputs(pow_sup)
        # this time is needful to fully unload DUT
        time.sleep(1)
        gen_fun.disable_output(generator)
        time.sleep(0.5)

        # zmien parametry
        pow_fun.update_device(pow_sup, voltage, pow_sup_ch)
        gen_fun.update_device(generator, frequency)
        time.sleep(1)

        # wlacz urzadzenia
        pow_fun.enable_outputs(pow_sup)
        gen_fun.enable_output(generator)
        osc_fun.enable_reading(scope)

        # stabilizacja sygnalow za pomoca opoznienia oraz dostrojenie parametrow na oscylskopie
        time.sleep(1)

        osc_fun.update_device(scope, frequency, voltage, voltage_ch, current_ch, trigger_ch, current_meas, voltage_meas)

        # zbierz dane
        osc_fun.download_data(scope=scope,
                              frequency=frequency,
                              voltage=voltage,
                              directory=new_file_directory,
                              current_ch=current_ch,
                              voltage_ch=voltage_ch)

        osc_fun.save_in_pendrive(scope=scope,
                                 frequency=frequency,
                                 voltage=voltage,
                                 directory=new_file_directory)
        time.sleep(3)

        print(
            "#######################################################################################################\n" * 2)
        print('\n' * 3)

# finish and close everythong
pow_fun.finish(pow_sup)
gen_fun.finish(generator)
osc_fun.finish(scope)

plt.show()
